@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # Copyright Notice:
-# Copyright 2016 DMTF. All rights reserved.
+# Copyright 2016, 2020 DMTF. All rights reserved.
 # License: BSD 3-Clause License. For full text see link: https://github.com/DMTF/Redfishtool/blob/master/LICENSE.md
 
 # redfishtool:  redfishtool.py
@@ -11,7 +11,7 @@
 #  Note: structure supports a future lib interface to the routines
 #        where the libWrapper is the interface
 #
-from redfishtool import main
+from redfishtoollib import main
 import sys
 
 if __name__ == "__main__":
